@@ -1,13 +1,14 @@
 use v5.16;
 use strict;
 use warnings;
-use utf8;
 
 package Art::World {
 
-  our $VERSION = '0.17_02';
+  our $VERSION = '0.17_03';
 
   use Zydeco authority => 'cpan:SMONFF', version   => $VERSION;
+  use Carp;
+  use utf8;
 
   role Active {
     method participate {
@@ -42,17 +43,6 @@ package Art::World {
     }
   }
 
-  # I guess it can be consummed by pretty much everything. Like idk, a place
-  # have a fame and an artwork too. But it was supposed to be more like an Agent
-  # thing in the beginning
-  role Fame {
-    has reputation ( is => rw, type => PositiveOrZeroNum );
-    # TODO If an Agent work is  collected, it's reputation should go up
-    method bump_fame( Num $gain = 1 ) {
-      $self->reputation( $self->reputation + $gain );
-    }
-  }
-
   role Concept {
     # Here should exist all the possible interractions of Concept entities
     method idea_of_project {}
@@ -60,6 +50,23 @@ package Art::World {
     # etc.
   }
 
+  # I guess it can be consummed by pretty much everything. Like idk, a place
+  # have a fame and an artwork too. But it was supposed to be more like an Agent
+  # thing in the beginning
+  role Fame {
+    has reputation ( is => rw, type => PositiveOrZeroNum ); #
+    # TODO If an Agent work is  collected, it's reputation should go up
+    method bump_fame( Num $gain = 1 ) {
+      if ( $self->reputation + $gain >= 0 ) {
+        $self->reputation( $self->reputation + $gain )
+      } else {
+        carp 'You tried to update reputation to a value smaller ' .
+          'than zero. Nothing changed.';
+      }
+      return $self->reputation
+    }
+  }
+
   role Space {
     has space;
   }
@@ -292,7 +299,13 @@ It has an handy C<bump_fame()> method that self-bump the fame count. It can be
 passed a positive C<Num>, a negative C<Num> (so that the fame will get lower)
 and even no parameter, in that case it will just add 1.
 
+  my $artist = Art::World->new_artist(
+    reputation => 0.42,
+    name => 'Questular Rontok'
+  );
 
+  say $artist->bump_fame;               # ==>  1.42
+  say $artist->bump_fame( 0.0042 );     # ==>  1.4242
 
 =head2 Market
 
